[![Python tests](https://github.com/cnpryer/pylamine/actions/workflows/python-tests.yaml/badge.svg)](https://github.com/cnpryer/pylamine/actions/workflows/python-tests.yaml)
[![Rust tests](https://github.com/cnpryer/pylamine/actions/workflows/rust-tests.yaml/badge.svg)](https://github.com/cnpryer/pylamine/actions/workflows/rust-tests.yaml)
[![latest release](https://img.shields.io/pypi/v/pylamine.svg)](https://pypi.org/project/pylamine/)

# pylamine

Python bindings for [`Calamine`](https://github.com/tafia/calamine).

## Contributing

See [CONTRIBUTING.md](./CONTRIBUTING.md).

## Credits

Credits to [`python-calamine`](https://github.com/dimastbk/python-calamine) for getting this started with `get_sheet_data` and `get_sheet_names`! 👏
